@@ -176,10 +176,6 @@ class CompleteScalingInterval:
 
 @jsii.interface(jsii_type="@aws-cdk/aws-autoscaling-common.IRandomGenerator")
 class IRandomGenerator(typing_extensions.Protocol):
-    @builtins.staticmethod
-    def __jsii_proxy_class__() -> typing.Type["_IRandomGeneratorProxy"]:
-        return _IRandomGeneratorProxy
-
     @jsii.member(jsii_name="nextBoolean")
     def next_boolean(self) -> builtins.bool:
         ...
@@ -208,6 +204,9 @@ class _IRandomGeneratorProxy:
         '''
         return typing.cast(jsii.Number, jsii.invoke(self, "nextInt", [min, max]))
 
+# Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
+typing.cast(typing.Any, IRandomGenerator).__jsii_proxy_class__ = lambda : _IRandomGeneratorProxy
+
 
 @jsii.data_type(
     jsii_type="@aws-cdk/aws-autoscaling-common.ScalingInterval",
